==> PyCPP-0.0.4.tar.gz: PyCPP-0.0.4/README.md <==
<p align=center>

  <img height="128px" src="https://user-images.githubusercontent.com/45269106/103140882-5d82a000-46ec-11eb-8728-bbde13d2b244.png"/>

  <br>
  <span>PyCPP is a simple tool for wrapping and using <a href="https://github.com/topics/cpp">C++</a> functions and libraries.</span>
  <br>
  <a target="_blank" href="https://www.python.org/downloads/" title="Python version"><img src="https://img.shields.io/badge/python-%3E=_3.6-green.svg"></a>
  <a target="_blank" href="LICENSE" title="License: MIT"><img src="https://img.shields.io/github/license/commander07/PyCPP"></a>
  <!-- <a target="_blank" href="https://sokobot.cf"><img alt="Website" src="https://img.shields.io/website?down_color=red&down_message=DOWN&style=flate&up_color=green&up_message=UP&url=https%3A%2F%2Fsokobot.cf"></a> -->

</p>

<p align="center">
  <a href="#installation">Installation</a>
  &nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
  <a href="#resources">Resources</a>
  &nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
  <a href="#contributing">Contributing</a>
</p>

## Installation

### Windows

```console
# clone the repo
$ git clone https://github.com/Commander07/PyCPP.git

# change the working directory to PyCPP
$ cd PyCPP

# install the requirements
$ python3 -m pip install -r requirements.txt
```

### Linux

```console
# clone the repo
$ git clone https://github.com/Commander07/PyCPP.git

# change the working directory to PyCPP
$ cd PyCPP

# install the requirements
$ python3 -m pip install -r requirements.txt
```

## Usage

```console
# Call pycpp.py and create python package in the output folder which includes the wrapped dll
$ python3 -m pycpp <DLL Name> <Output>
```

## Resources

- [Online Documentation](about:blank) for official documentation.

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change. Feel free to create a fork and use the code.

==> PyCPP-0.0.5.tar.gz: PyCPP-0.0.5/README.md <==
<p align=center>

  <img height="128px" src="https://user-images.githubusercontent.com/45269106/103140882-5d82a000-46ec-11eb-8728-bbde13d2b244.png"/>

  <br>
  <span>PyCPP is a simple tool for wrapping and using <a href="https://github.com/topics/cpp">C++</a> functions and libraries.</span>
  <br>
  <a target="_blank" href="https://www.python.org/downloads/" title="Python version"><img src="https://img.shields.io/badge/python-%3E=_3.6-green.svg"></a>
  <a target="_blank" href="LICENSE" title="License: MIT"><img src="https://img.shields.io/github/license/commander07/PyCPP"></a>
  <!-- <a target="_blank" href="https://sokobot.cf"><img alt="Website" src="https://img.shields.io/website?down_color=red&down_message=DOWN&style=flate&up_color=green&up_message=UP&url=https%3A%2F%2Fsokobot.cf"></a> -->

</p>

<p align="center">
  <a href="#installation">Installation</a>
  &nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
  <a href="#resources">Resources</a>
  &nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
  <a href="#contributing">Contributing</a>
</p>

## Installation

```console
# install via pypi
$ pip3 install PyCPP
```

## Usage

```console
# call pycpp.py and create python package in the output folder which includes the wrapped dll
$ python3 -m pycpp <DLL Name> <Output>
```

## Resources

- [Online Documentation](about:blank) for official documentation.
- [PyPi](https://pypi.org/project/PyCPP/) Package release page.

## Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change. Feel free to create a fork and use the code.
